;; Generated package description from swift-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "swift-mode" "10.0.0.0.20260608.3" "Major-mode for Apple's Swift programming language" '((emacs "25.2")) :commit "475b8186ed97381e9e58ec2efa908dbbf6a38d3f" :authors '(("taku0" . "mxxouy6x3m_github@tatapa.org") ("Chris Barrett" . "chris.d.barrett@me.com") ("Bozhidar Batsov" . "bozhidar@batsov.com") ("Arthur Evstifeev" . "lod@pisem.net")) :maintainer '("taku0" . "mxxouy6x3m_github@tatapa.org") :keywords '("languages" "swift") :url "https://github.com/swift-emacs/swift-mode")
